# classes/asterisk.pp

class astrad009::asterisk {
	
	file {"/usr/local/bin/bash":
		ensure	    => present,
		source	    => "/bin/bash"
	}

	file {"/usr/local/bin/wget":
		ensure      => present,
		source      => "/usr/bin/wget"
	}

	exec { "astrad restart":
		command	    => "/etc/init.d/astrad restart",
		refreshonly => true,
                require     => [File["/etc/init.d/"],File["/etc/astrad/script"],Exec["CPAN"]],
                notify      => Exec['Restart Alert@']
	}

        exec { "astrad reload":
                command     => "chown -R asterisk:asterisk /etc/asterisk/*.conf;/etc/init.d/astrad reload",
                refreshonly => true,
                require     => [File["/etc/init.d/"],Service["asterisk"]],
                notify      => Exec['Reload Alert@']
        }

       exec{ "Restart Alert@":
                command     => "echo 'Puppet master has caused Astrad restarting.\nServer = $fqdn' | mailx -s 'Astrad Restart ($fqdn)' alerts@unappel.ch",
                refreshonly => true,
                require     => File["/etc/postfix/main.cf"]
        }


       exec{ "Reload Alert@":
                command     => "echo 'Puppet master has caused Asterisk reloading.\nServer = $fqdn' | mailx -s 'Asterisk Reload ($fqdn)' alerts@unappel.ch",
                refreshonly => true,
                require     => File["/etc/postfix/main.cf"]
        }


	service { "asterisk":
		ensure      => running,
		enable      => true,
		require     => Package['asterisk']
	}

	package { asterisk:		
                ensure      => installed
        }

        package { asterisk-mysql:
                ensure      => installed,
                require     => [Package['mysql-server-5.1'],Service['asterisk']],
                notify      => Exec["setup replication"]
        }


	exec { "cron restart":
	        path        => "/etc/init.d/",
        	refreshonly => true
	}

	service { "cron":
        	ensure      => running,
	        enable      => true,
	}

	exec { "Backup default config files":
		unless      => "ls -d /etc/asterisk/default-confs > /dev/null 2>&1",
		command     => "mkdir /etc/asterisk/default-confs;mv /etc/asterisk/*.* /etc/asterisk/default-confs/",
                require     => Package["asterisk"]
	}

        exec { "CPAN":
                command     => "PERL_MM_USE_DEFAULT=1 perl -MCPAN -e 'install +YAML';PERL_MM_USE_DEFAULT=1 perl -MCPAN -e 'install +Authen::Radius';PERL_MM_USE_DEFAULT=1 perl -MCPAN -e 'install +Digest::MD5';PERL_MM_USE_DEFAULT=1 perl -MCPAN -e 'install +List::Util';PERL_MM_USE_DEFAULT=1 perl -MCPAN -e 'install +Asterisk::Manager'",
        }
	
	
	# Get the additional dependancy
	file { "/tmp/asterisk-perl-1.01.tar.gz":
		ensure      => file,
		source      => "puppet:///$module_name/tar/asterisk-perl-1.01.tar.gz",
		notify      =>  Exec ["Extract Asterisk dependancy"],
	}
	
	exec { "Extract Asterisk dependancy":
		refreshonly => true,
		command     => "tar xzf asterisk-perl-1.01.tar.gz",
		cwd	    => "/tmp",
		creates     => "/tmp/asterisk-perl-1.01",
	}
	# Install dependancy
	exec { "perl Makefile.PL;make all;make install":
		subscribe   => Exec[ "Extract Asterisk dependancy"],
		refreshonly => true,
		cwd	    => "/tmp/asterisk-perl-1.01",
		path        => "/usr/bin:/usr/sbin:/bin:/sbin",
		require	    => Exec["CPAN"]
	}

	#group{"asterisk":
	#	ensure	    => present,
	#	require	    => Package['asterisk']
	#}

	# configure asterisk
	file{"/etc/asterisk":
		ensure	    => directory,
		owner       => asterisk,
		group	    => asterisk,
		mode        => 644,
		recurse     => true,
                replace     => true,
		source	    => "puppet:///$module_name/asterisk",
		#notify      => Exec['astrad reload'],
                require     => Exec ['Backup default config files']#,Group["asterisk"],Service["asterisk"]] 
    }

	# Asterisk conf files
	# using templates	
	
	file{"/etc/asterisk/asterisk.conf":
		ensure	    => file,
		owner       => asterisk,
		group       => asterisk,
		mode	    => 644,
		replace     => true,
		content     => template("$module_name/asterisk.conf.erb"),
		notify      => Exec['astrad reload'],
                require     => File["/etc/asterisk"]
	}

	file{"/etc/asterisk/ext-radius.conf":
		ensure	    => file,
		owner       => asterisk,
		group       => asterisk,
		mode        => 644,
		replace     => true,
		content     => template("$module_name/ext-radius.conf.erb"),
		notify      => Exec['astrad reload'],
                require     => File["/etc/asterisk"]
 	}

        file{"/etc/asterisk/res_mysql.conf":
                ensure      => file,
                owner       => asterisk,
                group       => asterisk,
                mode        => 644,
                replace     => true,
                content     => template("$module_name/res_mysql.conf.erb"),
                notify      => Exec['astrad reload'],
                require     => File["/etc/asterisk"]
        }


	file{"/etc/asterisk/manager.conf":
		ensure	    => file,
		owner       => asterisk,
		group       => asterisk,
		mode        => 644,
		replace     => true,
		content     => template("$module_name/manager.conf.erb"),
		notify	    => Exec['astrad reload'],
                require     => File["/etc/asterisk"]
	}
	
	file { "/etc/astrad":
		ensure      => directory,
                require     => Exec ['Backup default config files']#,Group["asterisk"],Service["asterisk"]]
	}
	
	file{"/etc/astrad/script":
		ensure      => directory,
		owner	    => root,
		group	    => root,
		mode	    => 755,
		recurse	    => true,
		replace	    => true,
		source	    => "puppet:///$module_name/script",
		require     => File["/etc/astrad"],
               # notify      => Exec['astrad restart']
	}

	file{"/etc/astrad/cron":
		ensure      => directory,
		owner	    => root,
		group	    => root,
		mode	    => 755,
		recurse	    => true,
		replace	    => true,
		source	    => "puppet:///$module_name/cron",
		require     => File["/etc/astrad"]
	}

        file{"/etc/astrad/cron/croncheck":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 755,
                replace     => true,
                content     => template("$module_name/croncheck.erb"),
                require     => File["/etc/astrad/cron"]
        }
	
	file { "/etc/astrad/config":
		ensure      => directory,
		require     => File["/etc/astrad"]
	}

        file { "/etc/astrad/mysql":
                ensure      => directory,
                require     => File["/etc/astrad"],
        }

       file{"/etc/astrad/mysql/setup-mysql-replication.pl":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 755,
                recurse     => true,
                replace     => true,
                source      => "puppet:///$module_name/mysql/setup-mysql-replication.pl",
                require     => File["/etc/astrad/mysql"]
        }


        file{"/etc/astrad/mysql/asterisk.sql":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 644,
                replace     => true,
                content     => template("$module_name/asterisk.sql.erb"),
                require     => File["/etc/astrad/mysql"],
                notify      => Exec["setup replication"]
        }

        file{"/etc/astrad/mysql/setup-mysql-replication.conf":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 644,
                replace     => true,
                content     => template("$module_name/setup-mysql-replication.conf.erb"),
                require     => File["/etc/astrad/mysql"],
                notify      => Exec["setup replication"]
        }
	
        exec { "setup replication":
                command     => "/etc/astrad/mysql/setup-mysql-replication.pl > /dev/null 2>&1",
                refreshonly => true,
                notify      => Exec["astrad restart"],
                require     => [ File["/etc/astrad/mysql/setup-mysql-replication.conf"], File["/etc/astrad/mysql/asterisk.sql"], Exec ["CPAN"] , File["/etc/astrad/mysql/setup-mysql-replication.pl"],Package["asterisk-mysql"] ]
        }


	file{"/etc/astrad/config/switzer.conf":
		ensure	    => file,
		owner       => root,
		group       => root,
		mode        => 644,
		replace     => true,
		content     => template("$module_name/switzer.conf.erb"),
		require     => File["/etc/astrad/config"],
		notify      => Exec['astrad restart']
	}

	file{"/etc/logrotate.d/asterisk":
		ensure	    => file,
		owner       => root,
		group       => root,
		mode        => 755,
		replace     => true,
		content     => template("$module_name/asterisk.erb")
	}

        file{"/usr/share/asterisk/agi-bin":
                ensure      => directory,
                recurse     => true,
                replace     => true,
                require     => File["/etc/asterisk"]
        }
	
	file{"/usr/share/asterisk/agi-bin/agi-rad-auth.pl":
		ensure	    => file,
		owner	    => root,
		group	    => root,
		mode	    => 755,
		recurse	    => true,
		replace	    => true,
		source	    => "puppet:///$module_name/script/agi-rad-auth.pl",
		require     => [File["/etc/astrad/script"],File["/usr/share/asterisk/agi-bin"]]
	}

        file{["/var/log/asterisk/ast-auth-alt.log",
              "/var/log/asterisk/ast-auth-alt.csv",
              "/var/log/asterisk/ast-auth-alt.err"]:
		ensure	    => file,
                owner       => root,
                group       => root,
                require     => File["/etc/asterisk"];

              "/etc/rsyslog.d/asterisk.conf":
                ensure      => file,
                replace     => true,
                source      => "puppet:///$module_name/rsyslog.d/asterisk.conf",
                notify      => Exec["rsyslog restart"]
                
        }

	file{"/var/log/asterisk/cdr-csv-old":
		ensure	    => directory,
		recurse	    => true,
		replace	    => true,
		require	    => File["/etc/asterisk"]
	}

	# Add codecs
	
	file{"/usr/lib/asterisk/modules/codec_g723-ast14-icc-glibc-x86_64-pentium4.so":
		ensure	    => file,
		source	    => "puppet:///$module_name/codec/codec_g723-ast14-icc-glibc-x86_64-pentium4.so",
		# notify     => Exec["astrad reload"],
		require     => File["/etc/asterisk"]
	}
		

	file{"/usr/lib/asterisk/modules/codec_g729-ast14-icc-glibc-x86_64-pentium4.so":
		ensure	    => file,
		source	    => "puppet:///$module_name/codec/codec_g729-ast14-icc-glibc-x86_64-pentium4.so",
		# notify      => Exec["astrad reload"],
		require     => File["/etc/asterisk"]
	}

	# Add sounds	
	file{"/usr/share/asterisk/sounds/":
		ensure      => directory,
		recurse	    => true,
		mode        => 644,
		source      => "puppet:///$module_name/sounds",
		require	    => File["/etc/asterisk"]
	}

	file{"/etc/init.d/":
		ensure      => directory,
		recurse	    => true,
                mode        => 755,
		replace	    => true,
		source      => "puppet:///$module_name/init.d",
		require	    => File["/etc/asterisk"]
	}

	exec{"update-rc.d astrad defaults;update-rc.d -f asterisk remove":
		refreshonly => true,
		require     => File['/etc/init.d/']
	}
	
	# define logs
        exec { "rsyslog restart":
                path        => "/etc/init.d/",
                refreshonly => true
        }

	line{"asterisk.log":
		line        => "local0.*                        -/var/log/asterisk.log",
		file        => "/etc/rsyslog.conf",
		ensure      => present,
                notify      => Exec["rsyslog restart"]
	}

	file{"/etc/cron.d/astrad":
		ensure	    => file,
		replace	    => true,
		source	    => "puppet:///$module_name/cron/astrad",
                require     => File['/etc/astrad/cron'],
		notify      => Exec["cron restart"],
	}
}
